# pylint: skip-file
# Generated from Xkye.g4 by ANTLR 4.9
from antlr4 import ParseTreeListener

if __name__ is not None and "." in __name__:
    from .XkyeParser import XkyeParser
else:
    from XkyeParser import XkyeParser

# This class defines a complete listener for a parse tree produced by XkyeParser.
class XkyeListener(ParseTreeListener):

    # Enter a parse tree produced by XkyeParser#globe.
    def enterGlobe(self, ctx: XkyeParser.GlobeContext):
        pass

    # Exit a parse tree produced by XkyeParser#globe.
    def exitGlobe(self, ctx: XkyeParser.GlobeContext):
        pass

    # Enter a parse tree produced by XkyeParser#clutchheader.
    def enterClutchheader(self, ctx: XkyeParser.ClutchheaderContext):
        pass

    # Exit a parse tree produced by XkyeParser#clutchheader.
    def exitClutchheader(self, ctx: XkyeParser.ClutchheaderContext):
        pass

    # Enter a parse tree produced by XkyeParser#clutchdefheader.
    def enterClutchdefheader(self, ctx: XkyeParser.ClutchdefheaderContext):
        pass

    # Exit a parse tree produced by XkyeParser#clutchdefheader.
    def exitClutchdefheader(self, ctx: XkyeParser.ClutchdefheaderContext):
        pass

    # Enter a parse tree produced by XkyeParser#clutchsetheader.
    def enterClutchsetheader(self, ctx: XkyeParser.ClutchsetheaderContext):
        pass

    # Exit a parse tree produced by XkyeParser#clutchsetheader.
    def exitClutchsetheader(self, ctx: XkyeParser.ClutchsetheaderContext):
        pass

    # Enter a parse tree produced by XkyeParser#subclutchset.
    def enterSubclutchset(self, ctx: XkyeParser.SubclutchsetContext):
        pass

    # Exit a parse tree produced by XkyeParser#subclutchset.
    def exitSubclutchset(self, ctx: XkyeParser.SubclutchsetContext):
        pass

    # Enter a parse tree produced by XkyeParser#pairgroupset.
    def enterPairgroupset(self, ctx: XkyeParser.PairgroupsetContext):
        pass

    # Exit a parse tree produced by XkyeParser#pairgroupset.
    def exitPairgroupset(self, ctx: XkyeParser.PairgroupsetContext):
        pass

    # Enter a parse tree produced by XkyeParser#globalgroup.
    def enterGlobalgroup(self, ctx: XkyeParser.GlobalgroupContext):
        pass

    # Exit a parse tree produced by XkyeParser#globalgroup.
    def exitGlobalgroup(self, ctx: XkyeParser.GlobalgroupContext):
        pass

    # Enter a parse tree produced by XkyeParser#subclutch.
    def enterSubclutch(self, ctx: XkyeParser.SubclutchContext):
        pass

    # Exit a parse tree produced by XkyeParser#subclutch.
    def exitSubclutch(self, ctx: XkyeParser.SubclutchContext):
        pass

    # Enter a parse tree produced by XkyeParser#subclutchgroup.
    def enterSubclutchgroup(self, ctx: XkyeParser.SubclutchgroupContext):
        pass

    # Exit a parse tree produced by XkyeParser#subclutchgroup.
    def exitSubclutchgroup(self, ctx: XkyeParser.SubclutchgroupContext):
        pass

    # Enter a parse tree produced by XkyeParser#pairgroup.
    def enterPairgroup(self, ctx: XkyeParser.PairgroupContext):
        pass

    # Exit a parse tree produced by XkyeParser#pairgroup.
    def exitPairgroup(self, ctx: XkyeParser.PairgroupContext):
        pass

    # Enter a parse tree produced by XkyeParser#clutchspan.
    def enterClutchspan(self, ctx: XkyeParser.ClutchspanContext):
        pass

    # Exit a parse tree produced by XkyeParser#clutchspan.
    def exitClutchspan(self, ctx: XkyeParser.ClutchspanContext):
        pass

    # Enter a parse tree produced by XkyeParser#entity.
    def enterEntity(self, ctx: XkyeParser.EntityContext):
        pass

    # Exit a parse tree produced by XkyeParser#entity.
    def exitEntity(self, ctx: XkyeParser.EntityContext):
        pass

    # Enter a parse tree produced by XkyeParser#key.
    def enterKey(self, ctx: XkyeParser.KeyContext):
        pass

    # Exit a parse tree produced by XkyeParser#key.
    def exitKey(self, ctx: XkyeParser.KeyContext):
        pass

    # Enter a parse tree produced by XkyeParser#value.
    def enterValue(self, ctx: XkyeParser.ValueContext):
        pass

    # Exit a parse tree produced by XkyeParser#value.
    def exitValue(self, ctx: XkyeParser.ValueContext):
        pass

    # Enter a parse tree produced by XkyeParser#pair.
    def enterPair(self, ctx: XkyeParser.PairContext):
        pass

    # Exit a parse tree produced by XkyeParser#pair.
    def exitPair(self, ctx: XkyeParser.PairContext):
        pass

    # Enter a parse tree produced by XkyeParser#number.
    def enterNumber(self, ctx: XkyeParser.NumberContext):
        pass

    # Exit a parse tree produced by XkyeParser#number.
    def exitNumber(self, ctx: XkyeParser.NumberContext):
        pass

    # Enter a parse tree produced by XkyeParser#outstring.
    def enterOutstring(self, ctx: XkyeParser.OutstringContext):
        pass

    # Exit a parse tree produced by XkyeParser#outstring.
    def exitOutstring(self, ctx: XkyeParser.OutstringContext):
        pass

    # Enter a parse tree produced by XkyeParser#outstringsubset.
    def enterOutstringsubset(self, ctx: XkyeParser.OutstringsubsetContext):
        pass

    # Exit a parse tree produced by XkyeParser#outstringsubset.
    def exitOutstringsubset(self, ctx: XkyeParser.OutstringsubsetContext):
        pass


del XkyeParser
